Actions
=======

Adding new action
-----------------

.. image:: images/click-actions-contentview.png

.. image:: images/created-easyform-actions.png

.. image:: images/click-add-new-action.png

.. image:: images/add-new-action-overlay.png

.. image:: images/added-new-action.png

Edit action
-----------

.. image:: images/created-easyform-actions.png

Edit XML Actions Model
----------------------

.. image:: images/edit-xml-actions-model-button.png

.. image:: images/edit-xml-actions-model-page.png
